@@ -1113,16 +1113,19 @@ class Table:
 
         if len(df_labor) > 0:
             df_agg_labor = df_labor.pivot_table(values="worktime_result_hour", index="user_id", aggfunc=numpy.sum)
+            df_agg_labor["last_working_date"] = df_labor.pivot_table(values="date", index="user_id", aggfunc=numpy.max)
             df = df_agg_task_history.join(df_agg_labor)
         else:
             df = df_agg_task_history
             df["worktime_result_hour"] = 0
+            df["last_working_date"] = None
 
         phase_list = Table._get_phase_list(list(df.columns))
 
-        df = df[["worktime_result_hour"] + phase_list].copy()
+        df = df[["worktime_result_hour", "last_working_date"] + phase_list].copy()
         df.columns = pandas.MultiIndex.from_tuples(
-            [("actual_worktime_hour", "sum")] + [("monitored_worktime_hour", phase) for phase in phase_list]
+            [("actual_worktime_hour", "sum"), ("last_working_date", "")]
+            + [("monitored_worktime_hour", phase) for phase in phase_list]
         )
 
         df[("monitored_worktime_hour", "sum")] = df[[("monitored_worktime_hour", phase) for phase in phase_list]].sum(
